﻿using System.Drawing;
using System.Windows.Forms;

using DevExpress.XtraEditors;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 스크롤 X 좌표
        /// </summary>
        private int x = 0;

        /// <summary>
        /// 스크롤 Y 좌표
        /// </summary>
        private int y = 0;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 픽처 에디터를 설정한다.

            this.pictureEdit.Image = Properties.Resources.sample;

            #endregion
            #region 수평 스크롤바를 설정한다.

            this.hScrollBar.Width   = this.pictureEdit.Width;
            this.hScrollBar.Left    = this.pictureEdit.Left;
            this.hScrollBar.Top     = this.pictureEdit.Bottom;
            this.hScrollBar.Maximum = this.pictureEdit.Image.Width - this.pictureEdit.Width;

            #endregion
            #region 수직 스크롤바를 설정한다.

            this.vScrollBar.Height  = this.pictureEdit.Height;
            this.vScrollBar.Left    = this.pictureEdit.Left + this.pictureEdit.Width;
            this.vScrollBar.Top     = this.pictureEdit.Top;
            this.vScrollBar.Maximum = this.pictureEdit.Image.Height - this.pictureEdit.Height;

            #endregion
            #region 이벤트를 설정한다.

            this.pictureEdit.Paint += pictureEdit_Paint;
            this.hScrollBar.Scroll += hScrollBar_Scroll;
            this.vScrollBar.Scroll += vScrollBar_Scroll;

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 픽처 에디터 페인트시 처리하기 - pictureEdit_Paint(sender, e)

        /// <summary>
        /// 픽처 에디터 페인트시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void pictureEdit_Paint(object sender, PaintEventArgs e)
        {
            PictureEdit pictureEdit = sender as PictureEdit;

            e.Graphics.DrawImage
            (
                pictureEdit.Image,
                e.ClipRectangle,
                x,
                y,
                e.ClipRectangle.Width, 
                e.ClipRectangle.Height,
                GraphicsUnit.Pixel
            );
        }

        #endregion
        #region 수평 스크롤바 스크롤시 처리하기 - hScrollBar_Scroll(sender, e)

        /// <summary>
        /// 수평 스크롤바 스크롤시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void hScrollBar_Scroll(object sender, ScrollEventArgs e)
        {
            this.x = this.hScrollBar.Value;

            this.pictureEdit.Refresh();
        }

        #endregion
        #region 수직 스크롤바 스크롤시 처리하기 - vScrollBar_Scroll(sender, e)

        /// <summary>
        /// 수직 스크롤바 스크롤시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void vScrollBar_Scroll(object sender, ScrollEventArgs e)
        {
            this.y = this.vScrollBar.Value;

            pictureEdit.Refresh();
        }

        #endregion
    }
}